@@ -5,4 +5,5 @@ def randomInt(fromInt,toInt):
     while toInt != randomTime[index]:
         index = index + 1
         randomTime.append(fromInt - index)
-    print(int(random.choice(randomTime)))
+    result = int(random.choice(randomTime))
+    return result
